============================
 Invenio-OAuthClient v0.1.1
============================

Invenio-OAuthClient v0.1.1 was released on August 25, 2015.

About
-----

Invenio module that provides OAuth web authorization support.

*This is an experimental development preview release.*

Improved features
-----------------

- Improves the account setup for the CERN oauthclient.

Bug fixes
---------

- Adds missing `invenio_upgrader` dependency and amends past upgrade
  recipes following its separation into standalone package.

- Sends a validation email only if the option is enabled in the
  config.  (#4)

Installation
------------

   $ pip install invenio-oauthclient==0.1.1

Documentation
-------------

   http://invenio-oauthclient.readthedocs.org/en/v0.1.1

Happy hacking and thanks for flying Invenio-OAuthClient.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-oauthclient
|   URL: http://invenio-software.org
